==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/item/material/EnderAirItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.material;

import org.jetbrains.annotations.NotNull;

import vazkii.botania.common.entity.EnderAirBottleEntity;
import vazkii.botania.common.entity.EnderAirEntity;
import vazkii.botania.common.handler.BotaniaSounds;
import vazkii.botania.common.item.BotaniaItems;

import java.util.List;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1295;
import net.minecraft.class_1301;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_238;
import net.minecraft.class_2398;
import net.minecraft.class_3417;
import net.minecraft.class_3419;

public class EnderAirItem extends class_1792 {
	public EnderAirItem(class_1793 props) {
		super(props);
	}

	public static class_1271<class_1799> onPlayerInteract(class_1657 player, class_1937 world, class_1268 hand) {
		class_1799 stack = player.method_5998(hand);

		if (stack.method_7960() || !stack.method_31574(class_1802.field_8469)) {
			return class_1271.method_22430(stack);
		}

		if ((world.method_27983() == class_1937.field_25181 && isClearFromDragonBreath(world, player.method_5829().method_1014(3.5)))
				|| pickupFromEntity(world, player.method_5829().method_1014(1.0))) {

			if (!world.field_9236) {
				class_1799 enderAir = new class_1799(BotaniaItems.enderAirBottle);
				player.method_31548().method_7398(enderAir);
				stack.method_7934(1);
				world.method_8396(null, player.method_24515(), class_3417.field_15197, class_3419.field_15254, 0.5F, 1F);
			}

			return class_1271.method_22427(stack);
		}

		return class_1271.method_22430(stack);
	}

	public static boolean isClearFromDragonBreath(class_1937 world, class_238 aabb) {
		List<class_1295> list = world.method_8390(class_1295.class,
				aabb, entity -> entity != null && entity.method_5805()
						&& entity.method_5600().method_10295() == class_2398.field_11216);
		return list.isEmpty();
	}

	public static boolean pickupFromEntity(class_1937 level, class_238 area) {
		var entities = level.method_8390(EnderAirEntity.class, area, class_1301.field_6154);
		if (!entities.isEmpty()) {
			entities.get(0).method_31472();
			return true;
		}
		return false;
	}

	@NotNull
	@Override
	public class_1271<class_1799> method_7836(class_1937 world, class_1657 player, @NotNull class_1268 hand) {
		class_1799 stack = player.method_5998(hand);
		if (!player.method_31549().field_7477) {
			stack.method_7934(1);
		}

		world.method_43128(null, player.method_23317(), player.method_23318(), player.method_23321(), BotaniaSounds.enderAirThrow, class_3419.field_15248, 1F, 0.4F / (player.method_6051().method_43057() * 0.4F + 0.8F));

		if (!world.field_9236) {
			EnderAirBottleEntity b = new EnderAirBottleEntity(player, world);
			b.method_24919(player, player.method_36455(), player.method_36454(), 0F, 1.5F, 1F);
			world.method_8649(b);
		}
		return class_1271.method_29237(stack, world.field_9236);
	}
}

==> Botania-1.20.1-451-FABRIC-20251019.115504-18-sources.jar: vazkii/botania/common/item/material/EnderAirItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.material;

import org.jetbrains.annotations.NotNull;

import vazkii.botania.common.entity.EnderAirBottleEntity;
import vazkii.botania.common.entity.EnderAirEntity;
import vazkii.botania.common.handler.BotaniaSounds;
import vazkii.botania.common.item.BotaniaItems;

import java.util.List;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1295;
import net.minecraft.class_1301;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_239;
import net.minecraft.class_2398;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3959;
import net.minecraft.class_3965;
import net.minecraft.class_5712;

public class EnderAirItem extends class_1792 {
	public EnderAirItem(class_1793 props) {
		super(props);
	}

	public static class_1271<class_1799> onPlayerInteract(class_1657 player, class_1937 world, class_1268 hand) {
		class_1799 stack = player.method_5998(hand);

		if (stack.method_7960() || !stack.method_31574(class_1802.field_8469)) {
			return class_1271.method_22430(stack);
		}

		if ((world.method_27983() == class_1937.field_25181 && isClearFromDragonBreath(world, player.method_5829().method_1014(3.5)) && notAimingAtFluid(world, player))
				|| pickupFromEntity(world, player.method_5829().method_1014(1.0))) {

			if (!world.field_9236) {
				class_1799 enderAir = new class_1799(BotaniaItems.enderAirBottle);
				player.method_31548().method_7398(enderAir);
				stack.method_7934(1);
				world.method_8396(null, player.method_24515(), class_3417.field_15197, class_3419.field_15254, 0.5F, 1F);
				world.method_43275(player, class_5712.field_28167, player.method_19538());
			}

			return class_1271.method_29237(stack, world.method_8608());
		}

		return class_1271.method_22430(stack);
	}

	private static boolean notAimingAtFluid(class_1937 world, class_1657 player) {
		class_3965 hitResult = method_7872(world, player, class_3959.class_242.field_1347);
		if (hitResult.method_17783() == class_239.class_240.field_1332) {
			class_2338 pos = hitResult.method_17777();
			return world.method_8505(player, pos) && world.method_8316(pos).method_15769();
		}
		return true;
	}

	public static boolean isClearFromDragonBreath(class_1937 world, class_238 aabb) {
		List<class_1295> list = world.method_8390(class_1295.class,
				aabb, entity -> entity != null && entity.method_5805()
						&& entity.method_5600().method_10295() == class_2398.field_11216);
		return list.isEmpty();
	}

	public static boolean pickupFromEntity(class_1937 level, class_238 area) {
		var entities = level.method_8390(EnderAirEntity.class, area, class_1301.field_6154);
		if (!entities.isEmpty()) {
			entities.get(0).method_31472();
			return true;
		}
		return false;
	}

	@NotNull
	@Override
	public class_1271<class_1799> method_7836(class_1937 world, class_1657 player, @NotNull class_1268 hand) {
		class_1799 stack = player.method_5998(hand);
		if (!player.method_31549().field_7477) {
			stack.method_7934(1);
		}

		world.method_43128(null, player.method_23317(), player.method_23318(), player.method_23321(), BotaniaSounds.enderAirThrow, class_3419.field_15248, 1F, 0.4F / (player.method_6051().method_43057() * 0.4F + 0.8F));

		if (!world.field_9236) {
			EnderAirBottleEntity b = new EnderAirBottleEntity(player, world);
			b.method_24919(player, player.method_36455(), player.method_36454(), 0F, 1.5F, 1F);
			world.method_8649(b);
		}
		return class_1271.method_29237(stack, world.field_9236);
	}
}
